package ch.hslu.appe.inventory.persistency;

import java.util.List;

import ch.hslu.appe.inventory.model.Product;
import ch.hslu.appe.inventory.model.StockOrder;

/**
 * Inventory / Stock Persistency Interface.
 * @author Felix Rohrer <felix.rohrer@stud.hslu.ch>
 */
public interface InventoryPersistency {

    /**
     * Adds a new Product to the Product List.
     * @param newProduct new Product to be added
     * @return true if success otherwise false
     */
    boolean addProduct(int newProduct);

    /**
     * Adds a new StockOrder.
     * @param stockOrder new StockOrder to be added
     * @return true if success otherwise false
     */
    boolean addStockOrder(StockOrder stockOrder);

    /**
     * Returns a Product based on ProductNumber.
     * @param productNumber requested ProductNumber
     * @return Product
     */
    Product getProduct(int productNumber);

    /**
     * Returns a list with all Products.
     * @return a list with all Products.
     */
    List<Product> getProducts();

    /**
     * Returns a list with active products.
     * @return list with active products.
     */
    List<Product> getProductsActive();

    /**
     * Returns a StockOrder based on StockOrderID.
     * @param stockOrderId requested StockOrderId
     * @return StockOrder
     */
    StockOrder getStockOrder(int stockOrderId);

    /**
     * Returns if a Product is active (true) or not (false).
     * @param productNumber requested ProductNumber
     * @return true if active otherwise false
     */
    boolean productActive(int productNumber);

    /**
     * Returns if a Product exists (true) or not (false).
     * @param productNumber requested ProductNumber
     * @return true if exists otherwise false
     */
    boolean productExists(int productNumber);

    /**
     * Updates the Active State of a Product.
     * @param productNumber the product-number
     * @param newState true if active otherwise false
     * @return true if success otherwise false
     */
    boolean setProductActiveState(int productNumber, boolean newState);

    /**
     * Updates a Product.
     * @param newProduct new product info
     * @return true if success otherwise false
     */
    boolean updateProduct(Product newProduct);

    /**
     * Updates the Stock, StockCount.
     * @param productNumber the product-number
     * @param newStock new Stock info
     * @return true if success otherwise false
     */
    boolean updateStock(int productNumber, int newStock);

    /**
     * Updates a StockOrder.
     * @param stockOrder new stockorder info
     * @return true if success otherwise false
     */
    boolean updateStockOrder(StockOrder stockOrder);

}
