package ch.hslu.appe.order.model;

import java.util.Date;

import ch.hslu.appe.usermanagement.model.Address;

/**
 * Contains all information about one Bill.
 * @author Felix Rohrer <felix.rohrer@stud.hslu.ch>
 */
public final class Bill {
    private int id;
    private Order order;
    private Address billAddress;
    private BillState state;
    private BillTyp typ;
    private Date invoiceDate;
    private Date paymentDueDate;
    private float dunningCosts;

    /**
     * Empty Default Constructor.
     */
    public Bill() {
        // empty default constructor
    }

    /**
     * gets the bill address.
     * @return the billaddress
     */
    public Address getBillAddress() {
        return billAddress;
    }

    /**
     * gets the dunning costs (Mahnspesen).
     * @return the dunningCosts
     */
    public float getDunningCosts() {
        return dunningCosts;
    }

    /**
     * Gets the unique product id, generated by the database.
     * @return the id
     */
    public int getId() {
        return id;
    }

    /**
     * gets the invoice date.
     * @return the invoiceDate
     */
    public Date getInvoiceDate() {
        return invoiceDate;
    }

    /**
     * Gets the order.
     * @return the order
     */
    public Order getOrder() {
        return order;
    }

    /**
     * gets the payment due date.
     * @return the paymentDueDate
     */
    public Date getPaymentDueDate() {
        return paymentDueDate;
    }

    /**
     * gets the state (open, paid, etc) of the bill.
     * @return the bill-state
     */
    public BillState getState() {
        return state;
    }

    /**
     * gets the typ (bill, reminder, etc.) of the bill.
     * @return the bill-typ
     */
    public BillTyp getTyp() {
        return typ;
    }

    /**
     * sets the bill address.
     * @param billAddress to be set
     */
    public void setBillAddress(final Address billAddress) {
        this.billAddress = billAddress;
    }

    /**
     * sets the dunning costs (Mahnspesen).
     * @param dunningCosts the dunningCoasts to set
     */
    public void setDunningCosts(final float dunningCosts) {
        this.dunningCosts = dunningCosts;
    }

    /**
     * Sets the Bill ID.
     * @param id billid
     */
    public void setId(final int id) {
        this.id = id;
    }

    /**
     * sets the invoice date.
     * @param invoiceDate the invoiceDate to set
     */
    public void setInvoiceDate(final Date invoiceDate) {
        this.invoiceDate = invoiceDate;
    }

    /**
     * sets the order id.
     * @param order the orderId to set
     */
    public void setOrder(final Order order) {
        this.order = order;
    }

    /**
     * sets the payment due date.
     * @param paymentDueDate the paymentDueDate to set
     */
    public void setPaymentDueDate(final Date paymentDueDate) {
        this.paymentDueDate = paymentDueDate;
    }

    /**
     * sets the state (open, paid, etc) of the bill.
     * @param state the state to set
     */
    public void setState(final BillState state) {
        this.state = state;
    }

    /**
     * sets the typ (bill, reminder, etc.) of the bill.
     * @param typ the typ to set
     */
    public void setTyp(final BillTyp typ) {
        this.typ = typ;
    }
}
