package ch.hslu.appe.usermanagement.filter;

import java.util.HashMap;
import java.util.Map;

import ch.hslu.appe.filter.Filter;
import ch.hslu.appe.usermanagement.model.User;

/**
 * User Filter.
 */
public final class UserFilter implements Filter<User> {

    private int id;
    private String login;
    private String prename;
    private String surname;
    private String role;

    @Override
    public Map<String, Object> getFilter() {

        final Map<String, Object> filter = new HashMap<String, Object>();

        // Add filter criteria
        if (id > 0) {
            filter.put("id", id);
        }

        if (login != null && !login.isEmpty()) {
            filter.put("login", login);
        }

        if (prename != null && !prename.isEmpty()) {
            filter.put("prename", prename);
        }

        if (surname != null && !surname.isEmpty()) {
            filter.put("surname", surname);
        }

        if (role != null && !role.isEmpty()) {
            filter.put("role", role);
        }

        return filter;
    }

    /**
     * Return the ID.
     * @return id
     */
    public int getId() {
        return id;
    }

    /**
     * Return the Login.
     * @return login
     */
    public String getLogin() {
        return login;
    }

    /**
     * Return Prename.
     * @return prename
     */
    public String getPrename() {
        return prename;
    }

    /**
     * Return Role.
     * @return role
     */
    public String getRole() {
        return role;
    }

    /**
     * Return Surname.
     * @return surname
     */
    public String getSurname() {
        return surname;
    }

    @Override
    public boolean match(final User other) {

        // Check the id
        if (id > 0 && other.getId() != id) {
            return false;
        }

        // Check the login
        if (login != null && !login.isEmpty() && !other.getLogin().matches(login.replace("%", ".*"))) {
            return false;
        }

        // Check the prename
        if (prename != null && !prename.isEmpty() && !other.getPrename().matches(prename.replace("%", ".*"))) {
            return false;
        }

        // Check the surname
        if (surname != null && !surname.isEmpty() && !other.getSurname().matches(surname.replace("%", ".*"))) {
            return false;
        }

        // Check the role
        if (role != null && !role.isEmpty() && !other.getRole().matches(role.replace("%", ".*"))) {
            return false;
        }

        return true;
    }

    /**
     * Set the ID.
     * @param id to be set
     */
    public void setId(final int id) {
        this.id = id;
    }

    /**
     * Set the Login.
     * @param login to be set
     */
    public void setLogin(final String login) {
        this.login = login;
    }

    /**
     * Set the Prename.
     * @param prename to be set
     */
    public void setPrename(final String prename) {
        this.prename = prename;
    }

    /**
     * Set the Role.
     * @param role to be set
     */
    public void setRole(final String role) {
        this.role = role;
    }

    /**
     * Set the Surname.
     * @param surname to be set
     */
    public void setSurname(final String surname) {
        this.surname = surname;
    }
}
