package ch.hslu.appe.usermanagement.persistency;

import java.util.List;

import ch.hslu.appe.usermanagement.filter.UserFilter;
import ch.hslu.appe.usermanagement.model.User;

/**
 * User Persistency Interface.
 */
public interface UserPersistency {

    /**
     * Persists a new user.
     * @param user The user object
     * @return Returns true on success, otherwise false
     */
    boolean addUser(User user);

    /**
     * Deletes a single user by its unique id.
     * @param id The user id
     * @return Returns true on success, otherwise false
     */
    boolean deleteUser(int id);

    /**
     * Deletes a single user by its login name.
     * @param login The user login
     * @return Returns true on success, otherwise false
     */
    boolean deleteUser(String login);

    /**
     * Deletes every address of a user except his home address.
     * @param userId The user id
     * @return Returns true on success, otherwise false
     */
    boolean deleteUserAddresses(int userId);

    /**
     * Gets a user from the database by its unique id.
     * @param id The login id
     * @return Returns an user object if the user exists, otherwise null
     */
    User getUser(int id);

    /**
     * Gets a user from the database by its unique login name.
     * @param login The login name
     * @return Returns an user object if the user exists, otherwise null
     */
    User getUser(String login);

    /**
     * Gets a all users.
     * @return Returns all users in a list
     */
    List<User> getUsers();

    /**
     * Gets users from the database, filtered by the submitted filter.
     * @param filter The filter
     * @return Returns a list of users
     */
    List<User> getUsers(UserFilter filter);

    /**
     * Updates a user in the database.
     * @param user The user object
     * @return Returns true if the user was successfully updated, otherwise false
     */
    boolean updateUser(User user);

    /**
     * Returns a value that indicates whether the specified user exists in the database.
     * @param userId The user id
     * @return Returns true if the user exists in the database, otherwise false
     */
    boolean userExists(int userId);

    /**
     * Returns a value that indicates whether the specified user exists in the database.
     * @param user The user object
     * @return Returns true if the user exists in the database, otherwise false
     */
    boolean userExists(User user);
}
